Enum dirigera::device::Device

source ·
pub enum Device {
    Blind(DeviceData),
    Controller(DeviceData),
    Gateway(DeviceData),
    Light(DeviceData),
    Outlet(DeviceData),
    Sensor(DeviceData),
}
A Device is a resource that is able to connect to the IKEA Dirigera hub - or the actual hub itself. It’s represented as an enum with one variant for each type rather than separate types for each content since the data for the devices are shared.

Variants



Blind(DeviceData)



Controller(DeviceData)



Gateway(DeviceData)



Light(DeviceData)



Outlet(DeviceData)



Sensor(DeviceData)

Implementations

source

impl Device

source

pub fn inner(&self) -> &DeviceData

Get a reference to the DeviceData for the Device.

source

pub fn inner_mut(&mut self) -> &mut DeviceData

Get a mutable reference to the DeviceData for the Device.