pub enum DeviceType {
    LightController,
    Light,
    Gateway,
    MotionSensor,
    Outlet,
}
A Device has both a type which is interpreted as the Device enum but also a device_type. They don’t always overlap.

Variants



LightController



Light



Gateway



MotionSensor



Outlet