Module scene

Module scene 

With the IKEA Home Smart app you can configure scenes that can be either triggered manually or on a schedule. Scenes are specific configuration for a set of devices such as color temperature, light level, blind level etcetera.

Structs

ActionData
Data for the action type which holds the Device id and attribute for the Scene.
AppTrigger
Events triggered from the app shows the state and when it was triggered.
Duration
Duration is just number of seconds from the trigger start.
Info
Each scene has a name and icon which is represented under the scene Info.
SceneAttributes
Attributes to the scene which shows information about on or off state and light level and color temperature for Devices that support those.
SceneData
Specific data for a scene such as what actions it will do and what Triggers it has.
SunriseSunsetTrigger
Sunrise and sunset events will sync with the user’s location and the response will show when the next trigger will happen and what EndTrigger the schedule has.
Time
Time shows what days to trigger for the specific time and what time that is.
TimeTrigger
Events triggered on time will show when the next trigger will happen and what EndTrigger the schedule has.

Enums

Action
A scene has a type to target for its action.
EndTrigger
An EndTrigger is something that will trigger the scene to end. It can be based on a duration, sunrise or sunset or a specific time.
Follow
Sunrise and sunset shows what days to trigger for sunrise or sunset if specific days and any offset from the sunrise or sunset time.
Scene
A Scene is represented by its type and will hold all the SceneData.
Trigger
A scene can be triggered from the app (or API), based on sunrise or sunset or on a specific time.