SunriseSunsetTrigger

Struct SunriseSunsetTrigger 

pub struct SunriseSunsetTrigger {
    pub id: String,
    pub disabled: bool,
    pub next_trigger_at: DateTime<Utc>,
    pub trigger: Follow,
    pub end_trigger_event: EndTrigger,
}
Sunrise and sunset events will sync with the user’s location and the response will show when the next trigger will happen and what EndTrigger the schedule has.

Fields

id: Stringdisabled: boolnext_trigger_at: DateTime<Utc>trigger: Followend_trigger_event: EndTrigger