pub enum Device {
Blind(DeviceData),
Controller(DeviceData),
Gateway(DeviceData),
Light(DeviceData),
Outlet(DeviceData),
Sensor(DeviceData),
}Expand description
A Device is a resource that is able to connect to the IKEA Dirigera hub - or the actual hub
itself. It’s represented as an enum with one variant for each type rather than separate types
for each content since the data for the devices are shared.
Variants
Blind(DeviceData)
Controller(DeviceData)
Gateway(DeviceData)
Light(DeviceData)
Outlet(DeviceData)
Sensor(DeviceData)
Implementations
sourceimpl Device
impl Device
sourcepub fn inner(&self) -> &DeviceData
pub fn inner(&self) -> &DeviceData
Get a reference to the DeviceData for the Device.
sourcepub fn inner_mut(&mut self) -> &mut DeviceData
pub fn inner_mut(&mut self) -> &mut DeviceData
Get a mutable reference to the DeviceData for the Device.