With the IKEA Home Smart app you can configure scenes that can be either triggered manually or on a schedule. Scenes are specific configuration for a set of devices such as color temperature, light level, blind level etcetera.
Structs
- Action
Data - Data for the action type which holds the
Deviceid and attribute for theScene. - AppTrigger
- Events triggered from the app shows the state and when it was triggered.
- Duration
- Duration is just number of seconds from the trigger start.
- Info
- Each scene has a name and icon which is represented under the scene
Info. - Scene
Attributes - Attributes to the scene which shows information about on or off state and light level and color
temperature for
Devices that support those. - Scene
Data - Specific data for a scene such as what actions it will do and what
Triggers it has. - Sunrise
Sunset Trigger - Sunrise and sunset events will sync with the user’s location and the response will show when
the next trigger will happen and what
EndTriggerthe schedule has. - Time
- Time shows what days to trigger for the specific time and what time that is.
- Time
Trigger - Events triggered on time will show when the next trigger will happen and what
EndTriggerthe schedule has.
Enums
- Action
- A scene has a type to target for its action.
- EndTrigger
- An
EndTriggeris something that will trigger the scene to end. It can be based on a duration, sunrise or sunset or a specific time. - Follow
- Sunrise and sunset shows what days to trigger for sunrise or sunset if specific days and any offset from the sunrise or sunset time.
- Scene
- A
Sceneis represented by itstypeand will hold all theSceneData. - Trigger
- A scene can be triggered from the app (or API), based on sunrise or sunset or on a specific time.