pub struct SceneData {
pub id: String,
pub info: Info,
pub scene_type: Option<String>,
pub actions: Vec<Action>,
pub commands: Vec<String>,
pub triggers: Vec<Trigger>,
pub undo_allowed_duration: u8,
pub created_at: DateTime<Utc>,
pub last_completed: Option<DateTime<Utc>>,
pub last_triggered: Option<DateTime<Utc>>,
pub last_undo: Option<DateTime<Utc>>,
}Expand description
Specific data for a scene such as what actions it will do and what Triggers it has.
Fields
id: Stringinfo: Infoscene_type: Option<String>actions: Vec<Action>commands: Vec<String>triggers: Vec<Trigger>undo_allowed_duration: u8created_at: DateTime<Utc>last_completed: Option<DateTime<Utc>>last_triggered: Option<DateTime<Utc>>last_undo: Option<DateTime<Utc>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for SceneData
impl<'de> Deserialize<'de> for SceneData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more